@@ -5,11 +5,16 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = '0.010';    # VERSION
+our $VERSION = '0.011';    # VERSION
 use Carp;
 use English '-no_match_vars';
 use Any::Moose;
-use Net::SFTP::Foreign 1.65;
+use Net::SFTP::Foreign 1.67;
+use Package::DeprecationManager -deprecations =>
+    { 'Net::SFTP::Foreign::Exceptional::new' => '0.11' };
+
+our $DEPRECATION
+    = 'Use the autodie parameter to Net::SFTP::Foreign directly.';
 
 our @CARP_NOT
     = qw(Net::SFTP::Foreign Class::MOP::Method::Wrapped Mouse::Meta::Class);
@@ -20,19 +25,20 @@ my @METHODS = grep { $ARG ne 'new' and $ARG ne 'DESTROY' }
 
 has _sftp =>
     ( is => 'ro', isa => 'Net::SFTP::Foreign', handles => \@METHODS );
-after \@METHODS => sub { shift->_sftp->die_on_error() };
 
 around BUILDARGS => sub {
     my ( $orig, $class ) = splice @ARG, 0, 2;
-    my $sftp = Net::SFTP::Foreign->new(@ARG);
-    $sftp->die_on_error();
-    return $class->$orig( _sftp => $sftp );
+
+    deprecated($DEPRECATION);
+
+    return $class->$orig(
+        _sftp => Net::SFTP::Foreign->new( @ARG, autodie => 1 ) );
 };
 
 __PACKAGE__->meta->make_immutable();
 1;
 
-# ABSTRACT: wraps Net::SFTP::Foreign to throw exceptions on failure
+# ABSTRACT: DEPRECATED. Wraps Net::SFTP::Foreign to throw exceptions on failure.
 
 __END__
 
@@ -43,11 +49,19 @@ cpants kwalitee diff irc mailto metadata placeholders
 
 =head1 NAME
 
-Net::SFTP::Foreign::Exceptional - wraps Net::SFTP::Foreign to throw exceptions on failure
+Net::SFTP::Foreign::Exceptional - DEPRECATED. Wraps Net::SFTP::Foreign to throw exceptions on failure.
 
 =head1 VERSION
 
-version 0.010
+version 0.011
+
+=head1 DEPRECATION NOTICE
+
+This module is deprecated in favor of
+L<"Net::SFTP::Foreign's own error handling"|Net::SFTP::Foreign/"Error handling">,
+specifically its C<autodie> mode which offers the same functionality that this
+module was originally developed to achieve.  You will receive a warning every
+time you call the C<new()> method on this module.
 
 =head1 SYNOPSIS
 
